[telepathy-glib/master] account: rename update_settings to update_parameters

Jonny Lamb jonny.lamb at collabora.co.uk
Mon Sep 28 07:39:37 PDT 2009


Signed-off-by: Jonny Lamb <jonny.lamb at collabora.co.uk>
---
 docs/reference/telepathy-glib-sections.txt |    4 ++--
 telepathy-glib/account.c                   |   18 +++++++++---------
 telepathy-glib/account.h                   |    4 ++--
 3 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/docs/reference/telepathy-glib-sections.txt b/docs/reference/telepathy-glib-sections.txt
index da74966..453541b 100644
--- a/docs/reference/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib-sections.txt
@@ -3003,8 +3003,8 @@ tp_account_reconnect_finish
 tp_account_is_enabled
 tp_account_is_valid
 tp_account_is_ready
-tp_account_update_settings_async
-tp_account_update_settings_finish
+tp_account_update_parameters_async
+tp_account_update_parameters_finish
 tp_account_remove_async
 tp_account_remove_finish
 tp_account_set_display_name_async
diff --git a/telepathy-glib/account.h b/telepathy-glib/account.h
index c2e3432..142bcbf 100644
--- a/telepathy-glib/account.h
+++ b/telepathy-glib/account.h
@@ -106,11 +106,11 @@ gboolean tp_account_is_valid (TpAccount *account);
 
 gboolean tp_account_is_ready (TpAccount *account);
 
-void tp_account_update_settings_async (TpAccount *account,
+void tp_account_update_parameters_async (TpAccount *account,
     GHashTable *parameters, const gchar **unset_parameters,
     GAsyncReadyCallback callback, gpointer user_data);
 
-gboolean tp_account_update_settings_finish (TpAccount *account,
+gboolean tp_account_update_parameters_finish (TpAccount *account,
     GAsyncResult *result, GError **error);
 
 void tp_account_remove_async (TpAccount *account,
diff --git a/telepathy-glib/account.c b/telepathy-glib/account.c
index b9d3bea..6b49b42 100644
--- a/telepathy-glib/account.c
+++ b/telepathy-glib/account.c
@@ -1406,19 +1406,19 @@ _tp_account_updated_cb (TpAccount *proxy,
 }
 
 /**
- * tp_account_update_settings_async:
+ * tp_account_update_parameters_async:
  * @account: a #TpAccount
  * @parameters: new parameters to set on @account
  * @unset_parameters: list of parameters to unset on @account
  * @callback: a callback to call when the request is satisfied
  * @user_data: data to pass to @callback
  *
  * Requests an asynchronous update of settings of @account. When the
  * operation is finished, @callback will be called. You can then call
  * tp_account_update_settings_finish() to get the result of the operation.
  */
 void
-tp_account_update_settings_async (TpAccount *account,
+tp_account_update_parameters_async (TpAccount *account,
     GHashTable *parameters,
     const gchar **unset_parameters,
     GAsyncReadyCallback callback,
@@ -1427,7 +1427,7 @@ tp_account_update_settings_async (TpAccount *account,
   GSimpleAsyncResult *result;
 
   result = g_simple_async_result_new (G_OBJECT (account),
-      callback, user_data, tp_account_update_settings_finish);
+      callback, user_data, tp_account_update_parameters_finish);
 
   tp_cli_account_call_update_parameters (account, -1, parameters,
       unset_parameters, _tp_account_updated_cb, result,
@@ -1435,17 +1435,17 @@ tp_account_update_settings_async (TpAccount *account,
 }
 
 /**
- * tp_account_update_settings_finish:
+ * tp_account_update_parameters_finish:
  * @account: a #TpAccount
  * @result: a #GAsyncResult
  * @error: a #GError to fill
  *
  * Finishes an async update of the settings on @account.
  *
  * Returns: %TRUE if the request succeeded, otherwise %FALSE
  */
 gboolean
-tp_account_update_settings_finish (TpAccount *account,
+tp_account_update_parameters_finish (TpAccount *account,
     GAsyncResult *result,
     GError **error)
 {
@@ -1454,7 +1454,7 @@ tp_account_update_settings_finish (TpAccount *account,
     return FALSE;
 
   g_return_val_if_fail (g_simple_async_result_is_valid (result,
-    G_OBJECT (account), tp_account_update_settings_finish), FALSE);
+    G_OBJECT (account), tp_account_update_parameters_finish), FALSE);
 
   return TRUE;
 }
@@ -1406,19 +1406,19 @@ _tp_account_updated_cb (TpAccount *proxy,
  * @user_data: data to pass to @callback
  *
- * Requests an asynchronous update of settings of @account. When the
+ * Requests an asynchronous update of parameters of @account. When the
  * operation is finished, @callback will be called. You can then call
@@ -1406,19 +1406,19 @@ _tp_account_updated_cb (TpAccount *proxy,
  * operation is finished, @callback will be called. You can then call
- * tp_account_update_settings_finish() to get the result of the operation.
+ * tp_account_update_parameters_finish() to get the result of the operation.
  */
 void
@@ -1435,17 +1435,17 @@ tp_account_update_settings_async (TpAccount *account,
  * @error: a #GError to fill
  *
- * Finishes an async update of the settings on @account.
+ * Finishes an async update of the parameters on @account.
  *
  * Returns: %TRUE if the request succeeded, otherwise %FALSE
-- 
1.5.6.5




More information about the telepathy-commits mailing list